@@ -57,7 +57,7 @@ the attribute :attr:`~HelpAppBase.help_layout`::
 
     main_app.help_layout = HelpScreenContainerOrWindow()
 
-:attr:`~HelpAppBase.help_layout is also used as a flag
+:attr:`~HelpAppBase.help_layout` is also used as a flag
 of the help mode activity. By assigning `None` to this
 attribute the help mode will be deactivated::
 
@@ -106,7 +106,7 @@ flow action `'open'`, the object `'item'` and the (optional)
 flow key `'123456'` is resulting in the following help text
 message id::
 
-    `'help_flow#open_item:123456'`
+    'help_flow#open_item:123456'
 
 If there is no need for a detailed message id that is taking
 the flow key into account, then simply create a help text
@@ -118,7 +118,7 @@ available help text files and if not found it will
 automatically fallback to use a message id without
 the flow key::
 
-    `'help_flow#open_item'`
+    'help_flow#open_item'
 
 .. hint::
     More information regarding the flow id you find in
@@ -234,11 +234,11 @@ from ae.i18n import default_language, get_f_string, translation
 from ae.gui_app import FLOW_KEY_SEP, module_globals, id_of_flow, MainAppBase                # type: ignore
 
 
-__version__ = '0.1.8'
+__version__ = '0.1.9'
 
 
-HELP_ID_PREFIX_FLOW = 'help_flow#'
-HELP_ID_PREFIX_STATE = 'help_app_state#'
+HELP_ID_PREFIX_FLOW = 'help_flow#'                                  #: message id prefix for flow change help texts
+HELP_ID_PREFIX_STATE = 'help_app_state#'                            #: message id prefix for app state change help texts
 
 IGNORED_HELP_FLOWS = (id_of_flow('close', 'flow_popup'), )          #: tuple of flow ids never search/show help text for
 IGNORED_HELP_STATES = ('flow_id', 'flow_path', 'win_rectangle')     #: tuple of app state names never searched help for
@@ -461,8 +461,8 @@ class HelpAppBase(MainAppBase, ABC):
         :param help_id:         help id to show help text for.
         :param help_vars:       variables used in the conversion of the f-string expression to a string.
                                 optional items passed to the help text renderer:
-                                    * `count`: optional number used for to render a pluralized help text.
-                                    * `self`: target widget for to show help text for.
+                                * `count`: optional number used for to render a pluralized help text.
+                                * `self`: target widget for to show help text for.
         :param key_suffix:      suffix to the key used if the translation is a dict.
         :param must_have:       pass True for to display error help text and console output if no help text exists.
         :return:                True if help text got found and displayed.
